Computes the linear (Euclidean) distance from a vector of differences between the coordinates of two points.
Examples
# Differences between two points in 3D
h <- c(3 - 0, 4 - 0, 0 - 0)
# Compute the Euclidean distance
deuclid(h)
#> [1] 5
Computes the linear (Euclidean) distance from a vector of differences between the coordinates of two points.
# Differences between two points in 3D
h <- c(3 - 0, 4 - 0, 0 - 0)
# Compute the Euclidean distance
deuclid(h)
#> [1] 5